@@ -282,7 +282,7 @@ as_dot_density <- function(
 #'
 #' A common use-case when working with time-series small-area Census data is to transfer data from one set of shapes (e.g. 2010 Census tracts) to another set of shapes (e.g. 2020 Census tracts). Population-weighted interpolation is one such solution to this problem that takes into account the distribution of the population within a Census unit to intelligently transfer data between incongruent units.
 #'
-#' The approach implemented here is based on Esri's data apportionment algorithm, in which an "apportionment layer" of points (referred to here as the \code{weights}) is used to determine how to weight areas of overlap between origin and target zones.  Users must supply a "from" dataset as an sf object (the dataset from which numeric columns will be interpolated) and a "to" dataset, also of class sf, that contains the target zones. A third sf object, the "weights", may be an object of geometry type \code{POINT} or polygons from which their centroids will be calculated.
+#' The approach implemented here is based on Esri's data apportionment algorithm, in which an "apportionment layer" of points (referred to here as the \code{weights}) is used to determine how to weight areas of overlap between origin and target zones.  Users must supply a "from" dataset as an sf object (the dataset from which numeric columns will be interpolated) and a "to" dataset, also of class sf, that contains the target zones. A third sf object, the "weights", may be an object of geometry type \code{POINT} or polygons from which points will be derived using \code{sf::st_point_on_surface()}.
 #'
 #' An intersection is computed between \code{from} and \code{to}, and a spatial join is computed between the intersection layer and the weights layer, represented as points.  A specified \code{weight_column} in \code{weights} will be used to determine the relative influence of each point on the allocation of values between \code{from} and \code{to}; if no weight column is specified, all points will be weighted equally.
 #'
@@ -292,8 +292,9 @@ as_dot_density <- function(
 #' @param to The target geometries (zones) to which numeric attributes will be interpolated.
 #' @param to_id (optional) An ID column in the target dataset to be retained in the output. For data obtained with tidycensus, this will be \code{"GEOID"} by convention.  If \code{NULL}, the output dataset will include a column \code{id} that uniquely identifies each row.
 #' @param extensive if \code{TRUE}, return weighted sums; if \code{FALSE}, return weighted means.
-#' @param weights An input spatial dataset to be used as weights. If the dataset is not of geometry type \code{POINT}, its centroids will be used.  For US-based applications, this will commonly be a Census block dataset obtained with the tigris or tidycensus packages.
+#' @param weights An input spatial dataset to be used as weights. If the dataset is not of geometry type \code{POINT}, it will be converted to points by the function with \code{sf::st_point_on_surface()}.  For US-based applications, this will commonly be a Census block dataset obtained with the tigris or tidycensus packages.
 #' @param weight_column (optional) a column in \code{weights} used for weighting in the interpolation process.  Typically this will be a column representing the population (or other weighting metric, like housing units) of the input weights dataset.  If \code{NULL} (the default), each feature in \code{weights} is given an equal weight of 1.
+#' @param weight_placement (optional) One of \code{"surface"}, where weight polygons are converted to points on polygon surfaces with \code{sf::st_point_on_surface()}, or \code{"centroid"}, where polygon centroids are used instead with \code{sf::st_centroid()}.  Defaults to \code{"surface"}.  This argument is not necessary if weights are already of geometry type \code{POINT}.
 #' @param crs (optional) The EPSG code of the output projected coordinate reference system (CRS). Useful as all input layers (\code{from}, \code{to}, and \code{weights}) must share the same CRS for the function to run correctly.
 #'
 #' @return A dataset of class sf with the geometries and an ID column from \code{to} (the target shapes) but with numeric attributes of \code{from} interpolated to those shapes.
@@ -349,6 +350,7 @@ interpolate_pw <- function(from,
                            extensive,
                            weights,
                            weight_column = NULL,
+                           weight_placement = c("surface", "centroid"),
                            crs = NULL) {
 
   # Check to make sure all inputs are valid
@@ -356,12 +358,12 @@ interpolate_pw <- function(from,
     stop("All inputs (from, to, and weights) must be sf objects.", call. = FALSE)
   }
 
-  if (!unique(sf::st_geometry_type(from)) %in% c("POLYGON", "MULTIPOLYGON")) {
+  if (!all(unique(sf::st_geometry_type(from)) %in% c("POLYGON", "MULTIPOLYGON"))) {
     stop("Input datasets `from` and `to` must both be of geometry type POLYGON or MULTIPOLYGON.",
          call. = FALSE)
   }
 
-  if (!unique(sf::st_geometry_type(to)) %in% c("POLYGON", "MULTIPOLYGON")) {
+  if (!all(unique(sf::st_geometry_type(to)) %in% c("POLYGON", "MULTIPOLYGON"))) {
     stop("Input datasets `from` and `to` must both be of geometry type POLYGON or MULTIPOLYGON.",
          call. = FALSE)
   }
@@ -380,6 +382,13 @@ interpolate_pw <- function(from,
     to$id <- as.character(1:nrow(to))
   }
 
+  # If the to_id is in the column names of from, it'll cause downstream problems
+  # and this can happen with tidycensus data with GEOID
+  # remove the column in this instance
+  if (to_id %in% names(from)) {
+    from[[to_id]] <- NULL
+  }
+
   # If the weight column is NULL, give all input shapes the same weight
   if (is.null(weight_column)) {
 
@@ -396,23 +405,38 @@ interpolate_pw <- function(from,
   from_id_sym <- rlang::sym(from_id)
   to_id_sym <- rlang::sym(to_id)
 
-  # Convert the input weights to centroids if input weights are not POINT
+  # Convert the input weights to points if input weights are not POINT
   is_point <- unique(sf::st_is(weights, "POINT"))
 
   # Accommodate input points if users want to bring their own
   if (is_point) {
-    weight_centroids <- weights
+    weight_points <- weights
   } else {
-    weight_centroids <- suppressWarnings(weights %>%
-                                           dplyr::select(!!weight_sym) %>%
-                                           sf::st_centroid())
+
+    # Use surface points or centroids for weight placement
+    weight_loc <- rlang::arg_match(weight_placement)
+
+    if (weight_loc == "surface") {
+
+      weight_points <- suppressWarnings(weights %>%
+                                          dplyr::select(!!weight_sym) %>%
+                                          sf::st_point_on_surface())
+
+    } else if (weight_loc == "centroid") {
+
+      weight_points <- suppressWarnings(weights %>%
+                                          dplyr::select(!!weight_sym) %>%
+                                          sf::st_centroid())
+
+    }
+
   }
 
 
 
   # Determine the denominator for the weights
   denominators <- from %>%
-    sf::st_join(weight_centroids, left = FALSE) %>%
+    sf::st_join(weight_points, left = FALSE) %>%
     sf::st_drop_geometry() %>%
     dplyr::group_by(!!from_id_sym) %>%
     dplyr::summarize(total = sum(!!weight_sym, na.rm = TRUE))
@@ -424,7 +448,7 @@ interpolate_pw <- function(from,
       sf::st_intersection(to) %>%
       dplyr::filter(sf::st_is(., c("POLYGON", "MULTIPOLYGON", "GEOMETRYCOLLECTION"))) %>%
       dplyr::mutate(intersection_id = dplyr::row_number()) %>%
-      sf::st_join(weight_centroids, left = FALSE) %>%
+      sf::st_join(weight_points, left = FALSE) %>%
       sf::st_drop_geometry() %>%
       dplyr::group_by(intersection_id) %>%
       dplyr::mutate(intersection_value = sum(!!weight_sym, na.rm = TRUE)) %>%
